Changes for bmi-topography
==========================

0.4 (2021-09-03)
----------------

- Support ALOS World 3D 30m products (#13)
- Support .asc and .img files (#14)
- Add format job to CI
- Use CITATION.cff file


0.3.2 (2021-04-23)
------------------

- Add citation recommendation with DOI
- Fix typos, update text in example notebooks
- Create CREDITS.md and rearrange docs


0.3.1 (2021-03-04)
------------------

- Install with conda
- Include shell script demonstrating CLI


0.3 (2021-02-25)
----------------

- Update README with overview and install instructions
- Write documentation


0.2 (2021-02-24)
----------------

- Implement BMI for Topography class from template generated by `bmipy-render`
- Include sample config file and Jupyter Notebook to demo BMI
- Add CI with GitHub Actions


0.1.1 (2021-02-22)
------------------

- Add Makefile rule to test upload to TestPyPI
- Test upload to TestPyPI


0.1 (2021-02-22)
----------------

- Create base library that calls OpenTopography API
- Create CLI for library
- Write tests for library and CLI
- Include demo Jupyter Notebook for library
